>From c6e46a043995b7a0889ee6192822fa176ca568eb Mon Sep 17 00:00:00 2001
From: Roiy Shpaner <roiy@cs.umanitoba.ca>
Date: Fri, 4 Apr 2014 12:20:19 -0500
Subject: [PATCH 07/10] MED Support - Browsing dialogs

---
 modules/gui/qt4/components/annotations_widget.cpp  |  99 ++++++++
 modules/gui/qt4/components/annotations_widget.hpp  |  51 ++++
 .../gui/qt4/components/events_layers_widget.cpp    | 281 +++++++++++++++++++++
 .../gui/qt4/components/events_layers_widget.hpp    |  61 +++++
 modules/gui/qt4/dialogs/annotations.cpp            |  83 ++++++
 modules/gui/qt4/dialogs/annotations.hpp            |  51 ++++
 modules/gui/qt4/dialogs/events_layers.cpp          | 148 +++++++++++
 modules/gui/qt4/dialogs/events_layers.hpp          |  72 ++++++
 modules/gui/qt4/dialogs_provider.cpp               |  66 +++++
 modules/gui/qt4/dialogs_provider.hpp               |   6 +
 10 files changed, 918 insertions(+)
 create mode 100644 modules/gui/qt4/components/annotations_widget.cpp
 create mode 100644 modules/gui/qt4/components/annotations_widget.hpp
 create mode 100644 modules/gui/qt4/components/events_layers_widget.cpp
 create mode 100644 modules/gui/qt4/components/events_layers_widget.hpp
 create mode 100644 modules/gui/qt4/dialogs/annotations.cpp
 create mode 100644 modules/gui/qt4/dialogs/annotations.hpp
 create mode 100644 modules/gui/qt4/dialogs/events_layers.cpp
 create mode 100644 modules/gui/qt4/dialogs/events_layers.hpp

diff --git a/modules/gui/qt4/components/annotations_widget.cpp b/modules/gui/qt4/components/annotations_widget.cpp
new file mode 100644
index 0000000..4cab937
--- /dev/null
+++ b/modules/gui/qt4/components/annotations_widget.cpp
@@ -0,0 +1,99 @@
+/*****************************************************************************
+ * annotations_widget.cpp : Annotations tool
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Author: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include "qt4.hpp"
+#include "components/annotations_widget.hpp"
+#include "components/interface_widgets.hpp"
+
+#include <QList>
+#include <QStringList>
+#include <QGridLayout>
+#include <QLineEdit>
+#include <QLabel>
+#include <QSpinBox>
+#include <QTextEdit>
+
+/**
+ * Annotation Widget
+ * Event annotations are displayed in this window
+ */
+AnnotationsWidget::AnnotationsWidget( QWidget *parent,
+                      intf_thread_t *_p_intf )
+                      : QWidget( parent ), p_intf( _p_intf )
+{
+    QGridLayout *annotationLayout = new QGridLayout( this );
+    annotationLayout->setVerticalSpacing( 0 );
+    
+    annotation_text = new QTextEdit;
+    annotation_text->setReadOnly( true );
+    annotationLayout->addWidget( annotation_text, 1, Qt::AlignCenter );
+}
+
+
+void AnnotationsWidget::update( )
+{
+    if ( !isVisible() ) return;
+
+    clear();
+
+    seeksegment_t *segments = NULL;
+
+    input_thread_t *p_input = playlist_CurrentInput( THEPL );
+
+    if (!p_input)
+        return;
+    
+    if ( input_Control( p_input, INPUT_GET_SEGMENT_AT, &segments, NULL, (int64_t)(-1), -1 )  /* get current selected annotation */
+        != VLC_SUCCESS )
+    {
+        vlc_object_release( p_input );
+        return;
+    }
+    
+    if ( segments )
+    {
+        if ( segments->psz_text )
+        {
+            annotation_text->setText( "Events Layer: " + QString(segments->psz_layerName) + " ("+ QString::number(segments->eventNum) + ") \n---------------------\n" +
+                             QString(segments->psz_text) );
+        }  
+
+        vlc_seeksegment_Delete ( segments );
+    }
+
+    vlc_object_release( p_input );
+}
+
+/*
+ * Clear all the metadata widgets
+ */
+void AnnotationsWidget::clear()
+{
+    annotation_text->clear();
+}
+
+
diff --git a/modules/gui/qt4/components/annotations_widget.hpp b/modules/gui/qt4/components/annotations_widget.hpp
new file mode 100644
index 0000000..754883a
--- /dev/null
+++ b/modules/gui/qt4/components/annotations_widget.hpp
@@ -0,0 +1,51 @@
+/*****************************************************************************
+ * annotations_widget.hpp : Annotations tool
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Author: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifndef _ANNOTATIONSWIDGET_H_
+#define _ANNOTATIONSWIDGET_H_
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <QWidget>
+
+class QTextEdit;
+
+class AnnotationsWidget: public QWidget
+{
+    Q_OBJECT
+public:
+    AnnotationsWidget( QWidget *, struct intf_thread_t * );
+
+private:
+    struct intf_thread_t *p_intf;
+
+    QTextEdit *annotation_text;
+
+public slots:
+    void update( );
+    void clear();
+};
+
+#endif
diff --git a/modules/gui/qt4/components/events_layers_widget.cpp b/modules/gui/qt4/components/events_layers_widget.cpp
new file mode 100644
index 0000000..5f9010d
--- /dev/null
+++ b/modules/gui/qt4/components/events_layers_widget.cpp
@@ -0,0 +1,281 @@
+/*****************************************************************************
+ * events_layers_widget.cpp : Events Layers tool
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Author: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include "qt4.hpp"
+#include "components/events_layers_widget.hpp"
+#include "components/interface_widgets.hpp"
+#include "adapters/seeksegments.hpp"
+#include "adapters/seekpoints.hpp"
+#include "util/input_slider.hpp"
+
+#include <QList>
+#include <QGridLayout>
+#include <QHBoxLayout>
+#include <QStyleOptionSlider>
+#include <QStyle>
+#include <QPainter>
+
+/**
+ * Events Layers Widget
+ * Events Layers are displayed here
+ */
+EventsLayersWidget::EventsLayersWidget( QWidget *parent, QWidget * dialog,
+                      intf_thread_t *_p_intf )
+                      : QWidget( parent ), p_intf( _p_intf )
+{
+    EventsLayersLayout = new QGridLayout( dialog );
+    EventsLayersLayout->setHorizontalSpacing( 0 );
+    EventsLayersLayout->setVerticalSpacing( 0 );
+
+    parentDialog = dialog;
+
+    resize( parentDialog->size() );
+
+    setLayout( EventsLayersLayout );
+
+    QSizePolicy sizePolicy( QSizePolicy::Ignored, QSizePolicy::Expanding );
+
+    setSizePolicy( sizePolicy );
+
+    update( true );
+}
+
+
+void EventsLayersWidget::update( bool inputExists )
+{
+    clear();
+
+    if ( !inputExists )
+        return;
+        
+    input_thread_t *p_input = playlist_CurrentInput( THEPL );
+    if ( !p_input )
+        return;
+
+    int* pi_layers;
+    int* pi_selected;
+    int** ppi_selected;
+    char*** psz_layerNames;
+    if ( input_Control( p_input, INPUT_GET_LAYER_NAMES, &psz_layerNames, &pi_layers ) != VLC_SUCCESS )
+    {
+        vlc_object_release( p_input );
+        return;
+    }
+
+    if ( input_Control( p_input, INPUT_GET_SELECTED_LAYERS, &ppi_selected, &pi_selected ) != VLC_SUCCESS )
+    {
+        vlc_object_release( p_input );
+        return;
+    }
+    int i,j = 0;
+
+    //iLayers * vertical space;
+    for ( i = 0 ; i < *pi_layers ; i++ )
+    {
+        AddRemLayerButton *addRemButton = new AddRemLayerButton( this, p_intf );
+        static QSizePolicy sizePolicy( QSizePolicy::Fixed, QSizePolicy::Fixed );
+        sizePolicy.setHorizontalStretch( 0 );
+        sizePolicy.setVerticalStretch( 0 );
+
+        addRemButton->setSizePolicy( sizePolicy );
+        addRemButton->setFixedSize( QSize( 26, 26 ) );
+        addRemButton->setIconSize( QSize( 20, 20 ) );
+        addRemButton->setFocusPolicy( Qt::NoFocus );
+
+        addRemButton->setToolTip( qtr( N_("Add/Remove Events Layer") ) );
+
+        //connect action to button
+        addRemButton->iLayerId = i;
+        addRemButton->bAdded = false;
+
+        EventsLayersLayout->addWidget( addRemButton, i, 0, Qt::AlignLeft );
+
+
+        QLabel *layerName = new QLabel( qtr( (*psz_layerNames)[i] ) );
+        QPalette* palette = new QPalette();
+	    palette->setColor( QPalette::WindowText, segmentColors[i%9] );    //Colors repeat after 9
+	    layerName->setPalette( *palette );
+
+        EventsLayersLayout->addWidget( layerName, i, 1, Qt::AlignCenter );
+
+        if ( *pi_selected && (*ppi_selected)[j] == i ) 
+        {
+            addLayerStyle( i );     //Re-applies current selection style
+            addRemButton->bAdded = true;
+
+            if ( j < *pi_selected - 1 )
+                j++;
+        }
+        else
+            removeLayerStyle( i );
+
+
+        SeekSlider *slider = new SeekSlider( Qt::Horizontal, NULL, p_intf, false );
+
+        SeekSegments *events = new SeekSegments( slider, p_intf );
+        events->psz_layerName = strdup( (*psz_layerNames)[i] );
+        events->update( false );    /* updates for secondary sliders */
+        slider->setEvents( events );
+
+        SeekPoints *chapters = new SeekPoints( this, p_intf );
+        slider->setChapters( chapters );
+
+        int64_t length;
+        input_Control( p_input, INPUT_GET_LENGTH, &length );
+        slider->setPosition( 0, 0, length );
+
+        slider->iEventLayersId = i;
+        
+        CONNECT( slider, sliderDragged( float ),
+                 THEMIM->getIM(), sliderUpdate( float ) );
+
+        QSizePolicy slSizePolicy( QSizePolicy::MinimumExpanding, QSizePolicy::Fixed );
+        slider->setSizePolicy( slSizePolicy );
+
+        QHBoxLayout *sliderLayout = new QHBoxLayout( this );
+        sliderLayout->setMargin( 0 );
+        sliderLayout->setSpacing( 0 );
+        sliderLayout->addWidget( slider, Qt::AlignCenter );
+
+        EventsLayersLayout->addLayout( sliderLayout, i, 2 );
+
+        SegmentsTimeLabel *timeLabel = new SegmentsTimeLabel( p_intf, TimeLabel::Remaining );
+        timeLabel->psz_layerName = strdup( (*psz_layerNames)[i] );
+        EventsLayersLayout->addWidget( timeLabel, i, 3, Qt::AlignRight );
+    }
+
+    EventsLayersLayout->setColumnStretch( 2, 2 );
+
+    vlc_object_release( p_input );
+}
+
+
+void EventsLayersWidget::clear()
+{
+    for ( int i = 0; i < EventsLayersLayout->rowCount(); ++i )
+        for ( int j = 0; j < EventsLayersLayout->columnCount(); ++j )
+        {
+            QLayoutItem* item = EventsLayersLayout->itemAtPosition(i, j);
+            if (!item) 
+                continue;
+
+            EventsLayersLayout->removeItem(item);
+
+            if ( QLayout* childLayout = item->layout() )
+            {
+                while ( QLayoutItem* childItem = childLayout->takeAt(0) ) //Only slider currently
+                {
+                    childLayout->removeItem(childItem);
+                    delete childItem->widget();
+                    delete childItem;
+                }
+            }
+            else if ( item->widget() )
+                delete item->widget();
+            delete item;
+        }
+}
+
+//Add all layers
+void EventsLayersWidget::addAll()
+{
+    if ( !EventsLayersLayout )
+        return;
+
+    for ( int i = 0; i < EventsLayersLayout->rowCount(); ++i )
+    {
+        QLayoutItem* item = EventsLayersLayout->itemAtPosition( i, 0 );   //buttons
+        if (!item) 
+            continue;
+
+        AddRemLayerButton *addRemButton = (AddRemLayerButton*) item->widget();
+        addRemButton->extAddRemoveLayer( true );
+    }
+}
+
+//Remove all layers
+void EventsLayersWidget::removeAll()
+{
+    if ( !EventsLayersLayout )
+        return;
+
+    for ( int i = 0; i < EventsLayersLayout->rowCount(); ++i )
+    {
+        QLayoutItem* item = EventsLayersLayout->itemAtPosition( i, 0 );   //buttons
+        if (!item) 
+            continue;
+
+        AddRemLayerButton *addRemButton = (AddRemLayerButton*) item->widget();
+        addRemButton->extAddRemoveLayer( false );
+    }
+}
+
+void EventsLayersWidget::addLayerStyle( int iLayer )
+{
+    QLayoutItem* item = EventsLayersLayout->itemAtPosition( iLayer, 0 );   //Layer name
+    if (item) 
+    {
+        AddRemLayerButton *addRemButton = ( AddRemLayerButton* ) item->widget();
+        addRemButton->setIcon( QIcon( ":/minus" ) );
+    }
+
+    item = EventsLayersLayout->itemAtPosition( iLayer, 1 );   //Layer name
+    if (item) 
+    {
+        QLabel *layerName = (QLabel*) item->widget();
+        layerName->setStyleSheet( "font: 13pt; border-top: 2px solid green; border-bottom: 2px solid green; border-right: 2px solid green; border-left: 2px solid green;" );
+    }
+}
+
+void EventsLayersWidget::removeLayerStyle( int iLayer )
+{
+    QLayoutItem* item = EventsLayersLayout->itemAtPosition( iLayer, 0 );   //Layer name
+    if (item) 
+    {
+        AddRemLayerButton *addRemButton = ( AddRemLayerButton* ) item->widget();
+        addRemButton->setIcon( QIcon( ":/plus" ) );
+    }
+
+    item = EventsLayersLayout->itemAtPosition( iLayer, 1 );   //Layer name
+    if (item) 
+    {
+        QLabel *layerName = (QLabel*) item->widget();
+        layerName->setStyleSheet( "font: 13pt; ");
+    }
+}
+
+QSize EventsLayersWidget::sizeHint() const
+{
+    QSize org = QWidget::sizeHint();
+    return QSize( parentDialog->size().width(), org.height() );  /* Size of this widget should be previously saved width + preferred height */
+}
+
+EventsLayersWidget::~EventsLayersWidget()
+{
+    clear(); 
+    delete EventsLayersLayout;
+}
diff --git a/modules/gui/qt4/components/events_layers_widget.hpp b/modules/gui/qt4/components/events_layers_widget.hpp
new file mode 100644
index 0000000..fbca828
--- /dev/null
+++ b/modules/gui/qt4/components/events_layers_widget.hpp
@@ -0,0 +1,61 @@
+/*****************************************************************************
+ * events_layers_widget.hpp : Events Layers tool
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Author: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifndef _EVENTSLAYERSWIDGET_H_
+#define _EVENTSLAYERSWIDGET_H_
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <vlc_common.h>
+#include "components/controller.hpp"
+#include "util/input_slider.hpp"
+
+#include <QWidget>
+
+class QTextEdit;
+
+class EventsLayersWidget: public QWidget
+{
+    Q_OBJECT
+public:
+    EventsLayersWidget( QWidget *, QWidget * dialog, struct intf_thread_t * );
+    ~EventsLayersWidget();
+    QGridLayout *EventsLayersLayout;
+    void addLayerStyle( int iLayer );
+    void removeLayerStyle( int iLayer );
+    virtual QSize sizeHint() const;
+
+private:
+    struct intf_thread_t *p_intf;
+    QWidget *parentDialog;
+
+public slots:
+    void update(  bool inputExists );
+    void clear();
+    void addAll();
+    void removeAll();
+};
+
+#endif
diff --git a/modules/gui/qt4/dialogs/annotations.cpp b/modules/gui/qt4/dialogs/annotations.cpp
new file mode 100644
index 0000000..4c375da
--- /dev/null
+++ b/modules/gui/qt4/dialogs/annotations.cpp
@@ -0,0 +1,83 @@
+/*****************************************************************************
+ * annotations.cpp : annotations display
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Author: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include "dialogs/annotations.hpp"
+
+#include "main_interface.hpp" /* Needed for external MI size */
+#include "input_manager.hpp"
+
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <vlc_modules.h>
+
+AnnotationsDialog::AnnotationsDialog( intf_thread_t *_p_intf )
+               : QVLCDialog( (QWidget*)_p_intf->p_sys->p_mi, _p_intf )
+{
+#ifdef __APPLE__
+    setWindowFlags( Qt::Drawer );
+#else
+    setWindowFlags( Qt::Tool );
+#endif
+
+    setWindowOpacity( var_InheritFloat( p_intf, "qt-opacity" ) );
+    setWindowTitle( qtr( "Media Annotations" ) );
+    setWindowRole( "vlc-annotations" );
+
+    QVBoxLayout *layout = new QVBoxLayout( this );
+    layout->setContentsMargins( 0, 0, 0, 0 );
+    layout->setSpacing( 1 );
+
+    annotationsWidget = new AnnotationsWidget( this , p_intf );
+    layout->addWidget( annotationsWidget );
+
+
+    QDialogButtonBox *closeButtonBox = new QDialogButtonBox( Qt::Horizontal, this );
+    closeButtonBox->addButton(
+        new QPushButton( qtr("&Close"), this ), QDialogButtonBox::RejectRole );
+    layout->addWidget( closeButtonBox );
+    CONNECT( closeButtonBox, rejected(), this, close() );
+
+    /* Restore geometry or move this dialog on the left pane of the MI */
+    if( !restoreGeometry( getSettings()->value("AnnotationsPanel/geometry").toByteArray() ) )
+    {
+        resize( QSize( 400, 100 ) );
+
+        MainInterface *p_mi = p_intf->p_sys->p_mi;
+        if( p_mi && p_mi->x() > 50 )
+            move( ( p_mi->x() - frameGeometry().width() - 10 ), p_mi->y() );
+        else
+            move ( 450 , 0 );
+    }
+
+    CONNECT( THEMIM->getIM(), positionUpdated( float, int64_t, int64_t ),
+        annotationsWidget, update( ) );
+}
+
+AnnotationsDialog::~AnnotationsDialog()
+{
+    getSettings()->setValue("AnnotationsPanel/geometry", saveGeometry());
+}
+
diff --git a/modules/gui/qt4/dialogs/annotations.hpp b/modules/gui/qt4/dialogs/annotations.hpp
new file mode 100644
index 0000000..87cdda3
--- /dev/null
+++ b/modules/gui/qt4/dialogs/annotations.hpp
@@ -0,0 +1,51 @@
+/*****************************************************************************
+ * annotations.hpp : Media Annotations
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Author: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifndef QVLC_ANNOTATIONS_DIALOG_H_
+#define QVLC_ANNOTATIONS_DIALOG_H_ 1
+
+#include "components/annotations_widget.hpp"
+#include "util/qvlcframe.hpp"
+
+#include "util/singleton.hpp"
+
+class QTabWidget;
+class QTextEdit;
+
+class AnnotationsDialog : public QVLCDialog, public Singleton<AnnotationsDialog>
+{
+    Q_OBJECT
+private:
+    AnnotationsDialog( intf_thread_t * );
+    virtual ~AnnotationsDialog();
+
+    AnnotationsWidget *annotationsWidget;
+
+    QTextEdit *annotation_text;
+
+private slots:
+    friend class    Singleton<AnnotationsDialog>;
+};
+
+#endif
+
diff --git a/modules/gui/qt4/dialogs/events_layers.cpp b/modules/gui/qt4/dialogs/events_layers.cpp
new file mode 100644
index 0000000..17115b1
--- /dev/null
+++ b/modules/gui/qt4/dialogs/events_layers.cpp
@@ -0,0 +1,148 @@
+/*****************************************************************************
+ * events_layers.cpp : events_layers display
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include "dialogs/events_layers.hpp"
+
+#include "main_interface.hpp" /* Needed for external MI size */
+#include "input_manager.hpp"
+
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QScrollArea>
+#include <QScrollBar>
+#include <vlc_modules.h>
+
+EventLayersDialog::EventLayersDialog( intf_thread_t *_p_intf )
+               : QVLCDialog( (QWidget*)_p_intf->p_sys->p_mi, _p_intf )
+{
+#ifdef __APPLE__
+    setWindowFlags( Qt::Drawer );
+#else
+    setWindowFlags( Qt::Tool );
+#endif
+
+    setWindowOpacity( var_InheritFloat( p_intf, "qt-opacity" ) );
+    setWindowTitle( qtr( "Events Layers" ) );
+    setWindowRole( "vlc-eventLayers" );
+
+    if( !restoreGeometry( getSettings()->value("EventLayersPanel/geometry").toByteArray() ) )
+    {
+        resize( 300, 400 );
+    }
+
+    resetSize = false;
+
+    QVBoxLayout *layout = new QVBoxLayout( this );
+    layout->setContentsMargins( 0, 0, 0, 0 );
+    layout->setSpacing( 1 );
+
+    scroller = new QFittingScrollArea( this );
+    QSizePolicy sizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );
+
+    setSizePolicy( sizePolicy );
+    scroller->setSizePolicy( sizePolicy );
+    scroller->setFrameStyle( QFrame::NoFrame );
+    scroller->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    scroller->setWidgetResizable(true);
+
+    eventsLayersWidget = new EventsLayersWidget( scroller, this, p_intf );
+    scroller->setWidget( eventsLayersWidget );
+
+    layout->addWidget( scroller , 0 , Qt::AlignLeft | Qt::AlignTop);
+
+
+    QPushButton *addAllButton = new QPushButton( qtr("&Add All"), this );
+    QPushButton  *removeAllButton = new QPushButton( qtr("&Remove All"), this );
+
+    QDialogButtonBox *closeButtonBox = new QDialogButtonBox( Qt::Horizontal, this );
+    closeButtonBox->addButton(
+        new QPushButton( qtr("&Close"), this ), QDialogButtonBox::RejectRole );
+
+    buttonLayout = new QHBoxLayout( this );
+    buttonLayout->setSpacing( 0 );
+    buttonLayout->setContentsMargins( 0, 0, 0, 0 );
+    buttonLayout->addWidget( addAllButton , 0 , Qt::AlignLeft );
+    buttonLayout->addWidget( removeAllButton , 0 , Qt::AlignLeft );
+    buttonLayout->addStretch( 1 );
+    buttonLayout->addWidget( closeButtonBox, 0 , Qt::AlignRight  );
+    layout->addLayout( buttonLayout );
+    setLayout( layout );
+
+    CONNECT( addAllButton, released(), eventsLayersWidget, addAll() );
+    CONNECT( removeAllButton, released(), eventsLayersWidget, removeAll() );
+    CONNECT( closeButtonBox, rejected(), this, close() );
+    CONNECT( THEMIM->getIM(), eventsChanged( bool ), this, updateState( bool ) );
+
+    initSize();
+}
+
+EventLayersDialog::~EventLayersDialog()
+{
+    getSettings()->setValue("EventLayersPanel/geometry", saveGeometry());
+}
+
+void EventLayersDialog::updateState( bool inputExists )
+{
+    eventsLayersWidget->update( inputExists );
+
+    if ( !inputExists )
+    {
+        close();
+        resetSize = true;
+    }
+    else if ( resetSize )  /* reset size if input changed */
+    {
+        initSize();
+        resetSize = false;
+    }
+}
+
+void EventLayersDialog::resizeEvent( QResizeEvent *ev )
+{
+    scroller->resize( ev->size().width(), ev->size().height() - buttonLayout->sizeHint().height() );
+
+    update();
+}
+
+void EventLayersDialog::initSize()
+{
+    int initHeight = 400;
+    if ( eventsLayersWidget->sizeHint().height() < initHeight )
+        initHeight = eventsLayersWidget->sizeHint().height();
+    
+    resize( size().width(), initHeight + buttonLayout->sizeHint().height() + 1 );
+    scroller->viewport()->resize( size().width(), initHeight );
+}
+
+QSize EventLayersDialog::sizeHint() const
+{
+    return size();
+}
+
+QSize QFittingScrollArea::sizeHint() const
+{
+    return parentWidget()->size();
+}
\ No newline at end of file
diff --git a/modules/gui/qt4/dialogs/events_layers.hpp b/modules/gui/qt4/dialogs/events_layers.hpp
new file mode 100644
index 0000000..b8ca554
--- /dev/null
+++ b/modules/gui/qt4/dialogs/events_layers.hpp
@@ -0,0 +1,72 @@
+/*****************************************************************************
+ * events_layers.hpp : events layers dialogue
+ ****************************************************************************
+ * Copyright (C) 2014 the VideoLAN team
+ * $Id$
+ *
+ * Authors: Roiy Shpaner <roiy@cs.umanitoba.ca>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+
+#ifndef QVLC_EVENTS_LAYERS_DIALOG_H_
+#define QVLC_EVENTS_LAYERS_DIALOG_H_ 1
+
+#include "components/events_layers_widget.hpp"
+#include "util/qvlcframe.hpp"
+#include <QScrollArea>
+
+#include "util/singleton.hpp"
+
+class QTabWidget;
+class QTextEdit;
+class QHBoxLayout;
+
+class QFittingScrollArea : public QScrollArea
+{
+    Q_OBJECT
+
+public:
+    QFittingScrollArea( QWidget * parent ): QScrollArea( parent ){}
+    ~QFittingScrollArea(){}
+    virtual QSize sizeHint() const;
+};
+
+class EventLayersDialog : public QVLCDialog, public Singleton<EventLayersDialog>
+{
+    Q_OBJECT
+
+public:
+    virtual QSize sizeHint() const;
+
+private:
+    EventLayersDialog( intf_thread_t * );
+    virtual ~EventLayersDialog();
+
+    EventsLayersWidget *eventsLayersWidget;
+    QFittingScrollArea *scroller;
+    QHBoxLayout *buttonLayout;
+    bool resetSize;
+
+    virtual void resizeEvent( QResizeEvent *ev );
+
+private slots:
+    friend class    Singleton<EventLayersDialog>;
+    void updateState( bool inputExists );
+    void initSize();
+};
+
+#endif
+
diff --git a/modules/gui/qt4/dialogs_provider.cpp b/modules/gui/qt4/dialogs_provider.cpp
index eb31cf7..1dd63a0 100644
--- a/modules/gui/qt4/dialogs_provider.cpp
+++ b/modules/gui/qt4/dialogs_provider.cpp
@@ -56,6 +56,12 @@
 #include "dialogs/external.hpp"
 #include "dialogs/epg.hpp"
 #include "dialogs/errors.hpp"
+#include "dialogs/annotations.hpp"
+#include "dialogs/events_layers.hpp"
+#include "dialogs/event_properties.hpp"
+#include "dialogs/edit_event.hpp"
+#include "dialogs/delete_event.hpp"
+#include "dialogs/save_med.hpp"
 
 #include <QEvent>
 #include <QApplication>
@@ -203,6 +209,66 @@ void DialogsProvider::extendedDialog()
         extDialog->hide();
 }
 
+void DialogsProvider::annotationsDialog()
+{
+    AnnotationsDialog *anoDialog = AnnotationsDialog::getInstance( p_intf );
+
+    anoDialog->toggleVisible();
+}
+
+void DialogsProvider::eventLayersDialog()
+{
+    EventLayersDialog *layersDialog = EventLayersDialog::getInstance( p_intf );
+
+    layersDialog->toggleVisible();
+}
+
+void DialogsProvider::createEventDialog()
+{
+    /* Make sure only one editing winodw is open simultaneously */
+    if ( EditEventDialog::getInstance ( p_intf )->isVisible() )
+        EditEventDialog::getInstance ( p_intf )->close();
+    else if ( DeleteEventDialog::getInstance ( p_intf )->isVisible() )
+        DeleteEventDialog::getInstance ( p_intf )->close();
+
+    EventPropertiesDialog *createEventDialog = EventPropertiesDialog::getInstance( p_intf );
+
+    createEventDialog->toggleVisible();
+}
+
+void DialogsProvider::editEventDialog()
+{
+    /* Make sure only one editing winodw is open simultaneously */
+    if ( EventPropertiesDialog::getInstance ( p_intf )->isVisible() )
+        EventPropertiesDialog::getInstance ( p_intf )->close();
+    else if ( DeleteEventDialog::getInstance ( p_intf )->isVisible() )
+        DeleteEventDialog::getInstance ( p_intf )->close();
+
+    EditEventDialog *editEventDialog = EditEventDialog::getInstance ( p_intf );
+
+    editEventDialog->toggleVisible();
+}
+
+void DialogsProvider::deleteEventDialog()
+{
+    /* Make sure only one editing winodw is open simultaneously */
+    if ( EventPropertiesDialog::getInstance ( p_intf )->isVisible() )
+        EventPropertiesDialog::getInstance ( p_intf )->close();
+    else if ( EditEventDialog::getInstance ( p_intf )->isVisible() )
+        EditEventDialog::getInstance ( p_intf )->close();
+
+    DeleteEventDialog *deleteEventDialog = DeleteEventDialog::getInstance( p_intf );
+
+    deleteEventDialog->toggleVisible();
+}
+
+void DialogsProvider::saveMedDialog()
+{
+    SaveMedDialog *saveMedDialog = SaveMedDialog::getInstance( p_intf );
+
+    saveMedDialog->toggleVisible();
+}
+
 void DialogsProvider::synchroDialog()
 {
     ExtendedDialog *extDialog = ExtendedDialog::getInstance(p_intf );
diff --git a/modules/gui/qt4/dialogs_provider.hpp b/modules/gui/qt4/dialogs_provider.hpp
index 00bd37c..6e21eaa 100644
--- a/modules/gui/qt4/dialogs_provider.hpp
+++ b/modules/gui/qt4/dialogs_provider.hpp
@@ -124,6 +124,12 @@ public slots:
     void extendedDialog();
     void synchroDialog();
     void messagesDialog();
+    void annotationsDialog();
+    void eventLayersDialog();
+    void createEventDialog();
+    void editEventDialog();
+    void deleteEventDialog();
+    void saveMedDialog();
 #ifdef ENABLE_VLM
     void vlmDialog();
 #endif
-- 
1.8.4.msysgit.0

